@@ -20,33 +20,44 @@ already happened, to pass an adjusted timeout to the next step.
 """
 
 
-try:
-    from time import monotonic as _now
-except ImportError:
-    from time import time as _now
+from time import time as _now
 
 
-__version__ = '1.0.2'
+__version__ = '2.0.0'
 __all__ = ('Timeout',)
 
 
+def _name(obj):
+    return type(obj).__name__
+
+
+def _repr(obj, *args, **kwargs):
+    arguments = []
+    for argument in args:
+        arguments.append(repr(argument))
+    for name in kwargs:
+        arguments.append(name + '=' + repr(kwargs[name]))
+    return _name(obj) + '(' + ', '.join(arguments) + ')'
+
+
 class Timeout(object):
     # pylint: disable=too-few-public-methods
     # pylint: disable=bad-option-value,useless-object-inheritance
     """Counts down for the total timeout duration given"""
 
-    def __init__(self, timeout, now=None):
-        self._timeout = float(timeout)
+    def __init__(self, timeout, start=None, now=None):
+        self._timeout = timeout
         if now is None:
             now = _now
         self._now = now
-        self._start = now()
+        if start is None:
+            start = now()
+        self._start = start
 
     def __repr__(self):
-        time_left = repr(self.time_left())
         if self._now is _now:
-            return 'Timeout(' + time_left + ')'
-        return 'Timeout(' + time_left + ', now=' + repr(self._now) + ')'
+            return _repr(self, self._timeout, start=self._start)
+        return _repr(self, self._timeout, start=self._start, now=self._now)
 
     def __iter__(self):
         return TimeoutIterator(self)
@@ -56,7 +67,7 @@ class Timeout(object):
         now = self._now()
         elapsed = now - self._start
         remaining = self._timeout - elapsed
-        return max(remaining, 0.0)
+        return max(remaining, 0)
 
 
 class TimeoutIterator(object):
@@ -68,7 +79,7 @@ class TimeoutIterator(object):
         self._timeout = timeout
 
     def __repr__(self):
-        return 'TimeoutIterator(' + self._timeout + ')'
+        return _repr(self, self._timeout)
 
     def __iter__(self):
         return self
@@ -80,3 +91,11 @@ class TimeoutIterator(object):
         return time_left
 
     next = __next__  # Python 2 used `next` instead of ``__next__``
+
+
+# Portability to some minimal Python implementations:
+try:
+    Timeout.__name__
+except AttributeError:
+    Timeout.__name__ = 'Timeout'
+    TimeoutIterator.__name__ = 'TimeoutIterator'
